@@ -22,7 +22,7 @@
 
 // When compiled for the rustc compiler itself we want to make sure that this is
 // an unstable crate.
-#![cfg_attr(rustbuild, feature(staged_api))]
+#![cfg_attr(rustbuild, feature(staged_api, rustc_private))]
 #![cfg_attr(rustbuild, unstable(feature = "rustc_private", issue = "27812"))]
 
 pub mod html;
@@ -30,13 +30,16 @@ pub mod html;
 #[macro_use]
 extern crate bitflags;
 
-mod passes;
-mod parse;
+extern crate unicase;
+
 mod scanners;
 mod entities;
 mod escape;
 mod puncttable;
 mod utils;
+mod parse;
+mod tree;
+mod linklabel;
+mod strings;
 
-pub use passes::Parser;
-pub use parse::{Event, Tag, Options, OPTION_ENABLE_TABLES, OPTION_ENABLE_FOOTNOTES};
+pub use crate::parse::{Parser, Alignment, Event, Tag, Options, LinkType};
